Learn R Programming

surrosurvROC (version 0.1.0)

surrosurvROC-package: Surrogate Survival ROC

Description

Nonparametric and semiparametric estimations of the time-dependent ROC curve for an incomplete failure time data with surrogate failure time endpoints.

Arguments

Details

Package: isoph
Type: Package
Version: 0.1.0
Date: 2018-08-17
License: GPL (>= 2)

References

Yunro Chung and Yingye Zheng, Improving efficiency of evaluating prognostic accuracy of biomarkers for incomplete failure-time data with surrogate outcome (in progress)